"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var validateSatisfy_1 = require("./validators/validateSatisfy");
var validateEqual_1 = require("./validators/validateEqual");
var validateStrictlyEqual_1 = require("./validators/validateStrictlyEqual");
var validateInstanceOf_1 = require("./validators/validateInstanceOf");
var validateTypeOf_1 = require("./validators/validateTypeOf");
var validateTruthy_1 = require("./validators/validateTruthy");
var validateFalsy_1 = require("./validators/validateFalsy");
var validateGreaterThan_1 = require("./validators/validateGreaterThan");
var validateGreaterThanOrEqual_1 = require("./validators/validateGreaterThanOrEqual");
var validateLessThan_1 = require("./validators/validateLessThan");
var validateLessThanOrEqual_1 = require("./validators/validateLessThanOrEqual");
var validateCloseTo_1 = require("./validators/validateCloseTo");
var validateHasProperty_1 = require("./validators/validateHasProperty");
var validateCalled_1 = require("./validators/validateCalled");
var validateCalledTimes_1 = require("./validators/validateCalledTimes");
function expect(value) {
    return new Expect(value);
}
exports.expect = expect;
var Expect = /** @class */ (function () {
    function Expect(value) {
        this.negated = false;
        this.value = value;
    }
    Object.defineProperty(Expect.prototype, "not", {
        get: function () {
            if (!this.negated) {
                this.negated = true;
            }
            else {
                throw new TypeError('Cannot negate an already negated validator.');
            }
            return this;
        },
        enumerable: true,
        configurable: true
    });
    Expect.prototype.toEqual = function (expected) {
        return this.toSatisfy(validateEqual_1.validateEqual(expected));
    };
    Expect.prototype.toStrictlyEqual = function (expected) {
        return this.toSatisfy(validateStrictlyEqual_1.validateStrictlyEqual(expected));
    };
    Expect.prototype.toBeInstanceOf = function (constructor) {
        return this.toSatisfy(validateInstanceOf_1.validateInstanceOf(constructor));
    };
    Expect.prototype.toHaveTypeOf = function (type) {
        return this.toSatisfy(validateTypeOf_1.validateTypeOf(type));
    };
    Expect.prototype.toBeTruthy = function () {
        return this.toSatisfy(validateTruthy_1.validateTruthy);
    };
    Expect.prototype.toBeFalsy = function () {
        return this.toSatisfy(validateFalsy_1.validateFalsy);
    };
    Expect.prototype.toBeGreaterThan = function (value) {
        return this.toSatisfy(validateGreaterThan_1.validateGreaterThan(value));
    };
    Expect.prototype.toBeGreaterThanOrEqual = function (value) {
        return this.toSatisfy(validateGreaterThanOrEqual_1.validateGreaterThanOrEqual(value));
    };
    Expect.prototype.toBeLessThan = function (value) {
        return this.toSatisfy(validateLessThan_1.validateLessThan(value));
    };
    Expect.prototype.toBeLessThanOrEqual = function (value) {
        return this.toSatisfy(validateLessThanOrEqual_1.validateLessThanOrEqual(value));
    };
    Expect.prototype.toBeCloseTo = function (value, precision) {
        return this.toSatisfy(validateCloseTo_1.validateCloseTo(value, precision));
    };
    Expect.prototype.toHaveProperty = function (path, expected) {
        if (arguments.length === 1) {
            return this.toSatisfy(validateHasProperty_1.validateHasProperty(path));
        }
        else {
            return this.toSatisfy(validateHasProperty_1.validateHasProperty(path, expected));
        }
    };
    Expect.prototype.toBeCalled = function () {
        return this.toSatisfy(validateCalled_1.validateCalled);
    };
    Expect.prototype.toBeCalledTimes = function (count) {
        return this.toSatisfy(validateCalledTimes_1.validateCalledTimes(count));
    };
    Expect.prototype.toSatisfy = function (fn) {
        return validateSatisfy_1.validateSatisfy(this.value, this.negated, fn);
    };
    return Expect;
}());
