"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function joinPath(path, key) {
    var strKey = key + '';
    if (/^[a-z_]\w*$/i.test(strKey)) {
        return path + "." + strKey;
    }
    else if (/^\d+$/.test(strKey)) {
        return path + "[" + strKey + "]";
    }
    else {
        return path + "[" + JSON.stringify(strKey) + "]";
    }
}
exports.joinPath = joinPath;
function parsePath(path) {
    var result = [];
    if (!path.startsWith('[')) {
        path = '.' + path;
    }
    var i = 0;
    function test(re) {
        return path[i] && (typeof re === 'string'
            ? re === path[i]
            : re.test(path[i]));
    }
    function accept(re) {
        if (re && !test(re)) {
            return false;
        }
        else {
            var char = path[i++];
            return char;
        }
    }
    function expect(re) {
        if (!test(re)) {
            throw new SyntaxError('Invalid path');
        }
        else {
            var char = path[i++];
            return char;
        }
    }
    while (i < path.length) {
        var name = '';
        if (accept('.')) {
            name += expect(/[a-zA-Z_]/);
            while (test(/\w/)) {
                name += accept();
            }
        }
        else {
            expect('[');
            if (test(/\d/)) {
                while (test(/\d/)) {
                    name += accept();
                }
            }
            else {
                expect('"');
                var escaped = false;
                while (escaped || !test(/\"/)) {
                    if (accept('\\')) {
                        if (escaped) {
                            name += '\\';
                            escaped = false;
                        }
                        else {
                            escaped = true;
                        }
                    }
                    else if (escaped) {
                        escaped = false;
                        name += expect('"');
                    }
                    else {
                        name += accept();
                    }
                }
                expect('"');
            }
            expect(']');
        }
        result.push(name);
    }
    return result;
}
exports.parsePath = parsePath;
