"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var stringify_1 = require("../utils/stringify");
var path_1 = require("../utils/path");
function validateHasProperty(path, expected) {
    if (typeof path !== 'string') {
        throw new TypeError('argument 0 of .toHaveProperty must be a string');
    }
    var expectedString = stringify_1.stringify(expected);
    var parsedPath = path_1.parsePath(path);
    var checkValue = arguments.length === 2;
    return function (actual) {
        var actualString = stringify_1.stringify(actual);
        var _a = hasProperty(actual, parsedPath), result = _a.result, value = _a.value;
        if (!result) {
            return {
                success: false,
                message: "expected " + actualString + " to have property " + path,
                negatedMessage: ''
            };
        }
        else if (checkValue) {
            return {
                success: value === expected,
                message: "expected " + actualString + " to have property " + path + " " +
                    ("equal to " + expectedString),
                negatedMessage: "expected " + actualString + " not to have property " +
                    (path + " equal to " + expectedString + ", but it does")
            };
        }
        else {
            return {
                success: true,
                message: '',
                negatedMessage: "expected " + actualString + " not to have property " +
                    (path + ", but it does")
            };
        }
    };
}
exports.validateHasProperty = validateHasProperty;
function hasProperty(actual, parsedPath) {
    var current = actual;
    for (var _i = 0, parsedPath_1 = parsedPath; _i < parsedPath_1.length; _i++) {
        var key = parsedPath_1[_i];
        try {
            if (current[key] !== undefined || key in current) {
                current = current[key];
            }
            else {
                return { result: false, value: undefined };
            }
        }
        catch (_a) {
            return { result: false, value: undefined };
        }
    }
    return { result: true, value: current };
}
