"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AssertionError_1 = require("../AssertionError");
var hasOwnProperty_1 = require("../utils/hasOwnProperty");
function validateSatisfy(value, negated, fn) {
    var name = fn.name || 'toSatisfy';
    var result = fn(value);
    if (result instanceof Promise) {
        return result.then(function (value) { return processResult(value, negated, name); });
    }
    return processResult(result, negated, name);
}
exports.validateSatisfy = validateSatisfy;
function processResult(result, negated, name) {
    if (isValidationResult(result)) {
        if (result.success && negated) {
            throw new AssertionError_1.AssertionError(result.negatedMessage);
        }
        else if (!result.success && !negated) {
            throw new AssertionError_1.AssertionError(result.message);
        }
    }
    else {
        if (result && negated) {
            throw new AssertionError_1.AssertionError(name + " check succeded, but was expected to fail");
        }
        else if (!result && !negated) {
            throw new AssertionError_1.AssertionError(name + " check failed");
        }
    }
}
function isValidationResult(value) {
    // TODO: print warning for objects
    return value &&
        typeof value === 'object' &&
        hasOwnProperty_1.hasOwnProperty(value, 'success') &&
        hasOwnProperty_1.hasOwnProperty(value, 'message') &&
        hasOwnProperty_1.hasOwnProperty(value, 'negatedMessage');
}
